load_from_projects_dir

Function load_from_projects_dir 

pub fn load_from_projects_dir(
    projects_dir: &Path,
) -> Result<(Vec<SessionData>, GlobalDataQuality)>
Load all session data from a projects directory directly.

Unlike load_all which expects a Claude home directory (and appends projects/), this function takes the projects directory itself. Useful for loading data from archive directories like ~/.config/superpowers/conversation-archive/.