Module analysis

Module analysis 

Modules

overview
project
session
trend

Structs

AgentSummary
AggregatedTokens
CacheSavings
How much money was saved by cache hits vs paying full input price.
CostByCategory
OverviewResult
ProjectResult
ProjectSummary
SessionResult
SessionSummary
Session-level summary for overview reports and session ranking tables.
SubscriptionValue
TrendEntry
TrendResult
TurnCostBreakdown
TurnDetail

Type Aliases

DailyStats